@@ -27,6 +27,8 @@ initialize(validation)
 from Products.CMFCore.utils import getToolByName
 from Products.Archetypes import Field
 
+import criteria
+
 from raptus.multilanguagefields.interfaces import IMultilanguageAware, IMultilanguageField
 
 class MultilanguageAware(Persistent):
@@ -67,7 +69,7 @@ def init(self, data):
     ndata = []
     for v in data:
         if IMultilanguageAware.providedBy(v):
-            v = str(v)
+            v = v()
         ndata.append(v)
     Record.__init__(self, tuple(ndata))
 CatalogBrains.AbstractCatalogBrain.__init__ = init
@@ -150,6 +152,9 @@ def _getField(self, key, wrapped=False):
     return self.Schema().get(key)
 BaseObject.BaseObject.getField = _getField
 
+# ATContentTypes criteria monkey patch
+
+
 # Schemata monkey patch
 def _checkPropertyDupe(self, field, propname):
     check_value = getattr(field, propname, Schema._marker)
